# jpsuicide

A package for visualizing number of suicides in Japan

# How to install jpsuicide

$ pip install jpsuicide  
$ pip install tabula-py  
$ pip install matplotlib  
$ pip install japanize_matplotlib  
$ pip install pandas  

# How to run jpsuicide (example)

$ jpsuicide '東京都'  
